@@ -63,7 +63,7 @@ new CloudFrontToS3(scope: Construct, id: string, props: CloudFrontToS3Props);
 |cloudFrontWebDistribution|[`cloudfront.CloudFrontWebDistribution`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudfront.CloudFrontWebDistribution.html)|Returns an instance of cloudfront.CloudFrontWebDistribution created by the construct|
 |edgeLambdaFunctionVersion|[`lambda.Version`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Version.html)|Returns an instance of the edge Lambda function version created by the pattern.|
 |cloudFrontLoggingBucket|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/aws-s3-readme.html)|Returns an instance of the logging bucket for CloudFront WebDistribution.|
-|s3Bucket|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket created by the construct.|
+|s3Bucket?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket created by the construct.|
 |s3LoggingBucket?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket created by the construct as the logging bucket for the primary bucket.|
 
 ## Default settings
@@ -157,11 +157,6 @@ class CloudFrontToS3(
     ) -> aws_cdk.aws_cloudfront.CloudFrontWebDistribution:
         return jsii.get(self, "cloudFrontWebDistribution")
 
-    @builtins.property
-    @jsii.member(jsii_name="s3Bucket")
-    def s3_bucket(self) -> aws_cdk.aws_s3.Bucket:
-        return jsii.get(self, "s3Bucket")
-
     @builtins.property
     @jsii.member(jsii_name="cloudFrontLoggingBucket")
     def cloud_front_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
@@ -174,6 +169,11 @@ class CloudFrontToS3(
     ) -> typing.Optional[aws_cdk.aws_lambda.Version]:
         return jsii.get(self, "edgeLambdaFunctionVersion")
 
+    @builtins.property
+    @jsii.member(jsii_name="s3Bucket")
+    def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
+        return jsii.get(self, "s3Bucket")
+
     @builtins.property
     @jsii.member(jsii_name="s3LoggingBucket")
     def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
